<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<!--
  Created by Crane Softwrights Ltd. from the ISO file available at: 
  
  http://www.iso.org/schema/isosts/resources/schematron/ISOSTS_validation.sch
  
  With the following metadata:
    # $LastChangedRevision: 56925 $
    # $LastChangedDate: 2014-06-04 18:10:55 +0200 (Wed, 04 Jun 2014) $
-->
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:i="http://www.iso.org/isosts"
                xmlns:xlink="http://www.w3.org/1999/xlink"
                xmlns:tbx="urn:iso:std:iso:30042:ed-1"
                xmlns:mml="http://www.w3.org/1998/Math/MathML"
                xmlns:fct="http://www.iso.org/ns/fct"
                xmlns:css="http://www.iso.org/ns/css-parser"
                version="2.0"><!--Importing stylesheet additions--><xsl:output xmlns:sch="http://www.ascc.net/xml/schematron" method="text"/>
   <!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
<xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


<!--PROLOG-->


<!--XSD TYPES FOR XSLT2-->


<!--KEYS AND FUNCTIONS-->
<xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="fct:check-table"
                 as="element(fct:error)*">
        <xsl:param name="table" as="element()"/>
        <xsl:choose>
            <!-- check for valid col and rowspan values before running the table check to avoid conversion errors, 
                 additional schematron rules should be used to point to the exact td where this is wrong -->
            <xsl:when test="$table//(@colspan|@rowspan)[not(matches(., '^\d+$'))]">
                <fct:error>invalid value in colspan or rowspan found</fct:error>
            </xsl:when>
            <xsl:otherwise>
                <xsl:variable name="num-cols">
                    <xsl:choose>
                        <xsl:when test="$table//col">
                            <!-- take col definitions -->
                            <xsl:value-of select="count($table//col[not(@span)]) + sum($table/colgroup/col/@span)"/>
                        </xsl:when>
                        <xsl:when test="$table/thead">
                            <!-- take first row of table header -->
                            <xsl:value-of select="count($table/thead/tr[1]/th[not(@colspan)]) + sum($table/thead/tr[1]/th/@colspan)"/>
                        </xsl:when>
                        <xsl:when test="not($table/thead) and $table/tbody">
                            <!-- take first row of table body -->
                            <xsl:value-of select="count($table/tbody/tr[1]/td[not(@colspan)]) + sum($table/tbody/tr[1]/td/@colspan)"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <!-- count cols in first row -->
                            <xsl:value-of select="count($table/tr[1]/td[not(@colspan)]) + sum($table/tr[1]/td/@colspan)"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>
                <xsl:if test="$table/thead">
                    <xsl:copy-of select="fct:check-col-row-spans($num-cols, $table/thead/tr, 1, ())"/>
                </xsl:if>
                <xsl:if test="$table/tbody">
                    <xsl:copy-of select="fct:check-col-row-spans($num-cols, $table/tbody/tr, 1, ())"/>
                </xsl:if>        
                <xsl:if test="$table/tfoot">
                    <xsl:copy-of select="fct:check-col-row-spans($num-cols, $table/tfoot/tr, 1, ())"/>
                </xsl:if>                
                <xsl:if test="$table/tr">
                    <xsl:copy-of select="fct:check-col-row-spans($num-cols, $table/tr, 1, ())"/>
                </xsl:if>                
            </xsl:otherwise>
        </xsl:choose>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="fct:check-col-row-spans"
                 as="element(fct:error)*">
        <xsl:param name="num-cols" as="xs:integer"/>
        <xsl:param name="source-rows" as="element()+"/>
        <xsl:param name="index" as="xs:integer"/>
        <xsl:param name="row-spanned-cols" as="element()*"/>
        
        <!-- calculation of current number of columns is based on existing td/th elements and their colspans + any previous colums with rowspans (+ any colspan they have). 
             The spanned rows count already as colspan=1 so we have to substract 1 from every col with colspan. -->
        <xsl:variable name="curr-cols"
                    select="count($source-rows[$index]/*[not(@colspan)]) + sum($source-rows[$index]/*/@colspan) + count($row-spanned-cols) + sum($row-spanned-cols[@colspan]/@colspan) - count($row-spanned-cols[@colspan])"/>
        <!-- select columns with rowspan for next iteration. Take it from current row columns and previous -->
        <xsl:variable name="new-rowspan" as="element()*">
            <xsl:for-each select="($source-rows[$index]/*, $row-spanned-cols)[@rowspan &gt; 1]">
                <!-- decrement rowspan because this row is already processed -->
                <td rowspan="{@rowspan - 1}">
                    <!-- copy existing colspan -->
                    <xsl:copy-of select="@colspan"/>
                </td>
            </xsl:for-each>
        </xsl:variable>
        
        <xsl:if test="$curr-cols != $num-cols">
            <fct:error>
            <xsl:value-of select="node-name($source-rows/..)"/>: invalid col count in row=<xsl:value-of select="$index"/> (required=<xsl:value-of select="$num-cols"/>, calculated=<xsl:value-of select="$curr-cols"/>)</fct:error>
        </xsl:if>
        
        <xsl:if test="$index &lt; count($source-rows)">
            <xsl:copy-of select="fct:check-col-row-spans($num-cols, $source-rows, $index+1, $new-rowspan)"/>
        </xsl:if>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="css:parse"
                 as="element(css:css)*">
        <xsl:param name="style"/>
        <css:css>
            <xsl:if test="normalize-space($style)">                
                <xsl:for-each select="tokenize($style, ';')">
                    <xsl:variable name="css-def" select="."/>
                    <xsl:variable name="css-prop-name"
                             select="normalize-space(substring-before($css-def,':'))"/>
                    <xsl:variable name="css-prop-values"
                             select="normalize-space(substring-after($css-def,':'))"/>
                    <xsl:choose>
                        <xsl:when test="not($css-def)">
                            <!-- can be empty due to starting or ending ; -->
                        </xsl:when>
                        <xsl:when test="not($css-prop-values)">
                            <css:error>css property without values: <xsl:value-of select="$css-def"/>
                     </css:error>
                        </xsl:when>
                        <xsl:when test="not($css-prop-name)">
                            <css:error>empty css property name found before colon <xsl:value-of select="$css-def"/>
                     </css:error>
                        </xsl:when>
                        <xsl:when test="not(matches($css-prop-name,'^[a-z][a-z0-9\-]+$'))">
                            <css:error>invalid css property name: '<xsl:value-of select="$css-prop-name"/>'</css:error>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:element name="css:{$css-prop-name}">
                                <xsl:choose>
                                    <xsl:when test="$css-prop-name = 'font-family'">
                                        <xsl:copy-of select="css:build-font-family-values($css-prop-values)"/>
                                    </xsl:when>
                                    <xsl:when test="matches($css-prop-name, '.*color.*')">
                                        <xsl:copy-of select="css:build-color-values($css-prop-values)"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:copy-of select="css:build-generic-values($css-prop-values)"/>                                        
                                    </xsl:otherwise>
                                </xsl:choose>                                
                            </xsl:element>                            
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:for-each>
            </xsl:if>
        </css:css>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="css:build-generic-values"
                 as="element()*">
        <xsl:param name="value-string"/>
        <xsl:for-each select="tokenize($value-string, '\s')">
            <xsl:variable name="css-prop-value" select="normalize-space(.)"/>
            <xsl:choose>
                <xsl:when test="matches($css-prop-value, '^(\d+\.?\d*)(px|pt|em)?$')">
                    <xsl:analyze-string select="$css-prop-value" regex="^(\d+\.?\d*)(px|pt|em)?$">
                        <xsl:matching-substring>
                            <css:dimension>
                                <xsl:choose>
                                    <xsl:when test="regex-group(2)">
                                        <xsl:attribute name="unit" select="regex-group(2)"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:attribute name="unit">px</xsl:attribute>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:value-of select="regex-group(1)"/>
                            </css:dimension>
                        </xsl:matching-substring>
                    </xsl:analyze-string>
                </xsl:when>
                <xsl:when test="matches($css-prop-value, '^([a-z]+)\((.*)\)$')">
                    <xsl:analyze-string select="$css-prop-value" regex="^([a-z]+)\((.*)\)$">
                        <xsl:matching-substring>
                            <xsl:element name="css:{regex-group(1)}">
                                <xsl:value-of select="regex-group(2)"/>
                            </xsl:element>
                        </xsl:matching-substring>
                    </xsl:analyze-string>
                </xsl:when>
                <xsl:when test="contains($css-prop-value,':')">
                    <css:error>invalid style-value found: <xsl:value-of select="$css-prop-value"/>
               </css:error>
                </xsl:when>
                <xsl:when test="not(matches($css-prop-value,'^[a-z][a-z0-9\-]+$'))">
                    <css:error>invalid style-value found: <xsl:value-of select="$css-prop-value"/>
               </css:error>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:element name="css:{$css-prop-value}"/>                                            
                </xsl:otherwise>            
            </xsl:choose>
        </xsl:for-each>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="css:build-color-values"
                 as="element()*">
        <xsl:param name="value-string"/>
        <xsl:variable name="css-prop-value"
                    select="lower-case(normalize-space($value-string))"/>
        <xsl:choose>
            <!-- match hex colors such as #ff0000 -->
            <xsl:when test="matches($css-prop-value, '^#[a-f0-9]{6}$')">
                <css:color type="hex">
               <xsl:value-of select="$css-prop-value"/>
            </css:color>
            </xsl:when>
            <!-- match color names, such as blue -->
            <xsl:when test="matches($css-prop-value, '^\w+$')">
                <css:color type="named">
               <xsl:value-of select="$css-prop-value"/>
            </css:color>
            </xsl:when>
            <!-- match rgb(127, 127, 127) -->
            <xsl:when test="matches($css-prop-value, '^rgb\(\s*\d{1,3}\s*,\s*\d{1,3}\s*,\s*\d{1,3}\s*\)$')">
                <css:color type="rgb">
               <xsl:value-of select="$css-prop-value"/>
            </css:color>
            </xsl:when>
            <xsl:otherwise>
                <css:error>invalid value for color style-value found: <xsl:value-of select="$css-prop-value"/>
            </css:error>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="css:build-font-family-values"
                 as="element()*">
        <xsl:param name="value-string"/>
        <xsl:for-each select="tokenize($value-string, ',')">
            <css:font name="{.}"/>
        </xsl:for-each>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="fct:build-urn"
                 as="xs:string">
        <xsl:param name="iso-meta" as="element(iso-meta)"/>
        <xsl:variable name="urn">
         <xsl:text>iso:std:</xsl:text> 
         <xsl:value-of select="replace(lower-case($iso-meta/std-ident/originator), '/', '-')"/>
         <xsl:if test="$iso-meta/std-ident/doc-type != 'IS'">
             <xsl:text>:</xsl:text>
             <xsl:value-of select="replace(lower-case($iso-meta/std-ident/doc-type), '/', '-')"/>             
         </xsl:if>
         <xsl:text>:</xsl:text>
         <xsl:value-of select="$iso-meta/std-ident/doc-number"/>
         <xsl:if test="$iso-meta/std-ident/part-number != ''">
             <xsl:text>:-</xsl:text>
             <xsl:value-of select="$iso-meta/std-ident/part-number"/>
         </xsl:if>
         <xsl:if test="$iso-meta/doc-ident/release-version != 'IS'">
             <xsl:text>:</xsl:text>
             <xsl:value-of select="lower-case($iso-meta/doc-ident/release-version)"/>
         </xsl:if>
         <xsl:text>:ed-</xsl:text>
         <xsl:value-of select="$iso-meta/std-ident/edition"/>
         <xsl:text>:v</xsl:text>
         <xsl:value-of select="$iso-meta/std-ident/version"/>
         <xsl:if test="$iso-meta/std-ident/suppl-type != ''">
             <xsl:text>:</xsl:text>
             <xsl:value-of select="$iso-meta/std-ident/suppl-type"/>
             <xsl:text>:</xsl:text>
             <xsl:value-of select="$iso-meta/std-ident/suppl-number"/>
             <xsl:text>:v</xsl:text>
             <xsl:value-of select="$iso-meta/std-ident/suppl-version"/>
         </xsl:if>
         <xsl:text>:</xsl:text>
         <xsl:value-of select="string-join($iso-meta/content-language, ',')"/>
        </xsl:variable>
        <xsl:value-of select="normalize-space($urn)"/>
    </xsl:function>

   <!--DEFAULT RULES-->


<!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
<!--This mode can be used to generate prefixed XPath for humans-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
<!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
<xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
<xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters--><xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
<xsl:template match="/"><!--Root node processing collects all assertions--><xsl:variable xmlns:sch="http://www.ascc.net/xml/schematron" name="result">
         <xsl:apply-templates select="/" mode="M7"/>
      </xsl:variable>
      <xsl:if xmlns:sch="http://www.ascc.net/xml/schematron"
              test="normalize-space(string($result))">
         <xsl:message terminate="yes">
            <xsl:value-of select="string($result)" disable-output-escaping="yes"/>
         </xsl:message>
      </xsl:if>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


<!--PATTERN [GEN] General rules [META] Check metadata [FRONT] Check front [BODY] Check body [BACK] Check back [SEC] Check each sec [FN] Check footnote [NOTE] Check non-normative-note and non-normative-example [TAB] Check table-wrap [FOR] Check disp-formula [MML] Check mml:math [FIG] Check fig [TBX] tbx check [XREF] Check xref [SREF] Check standard references [LBL] Check label [GRP] Check graphic [LST] Check lists [BIB] Check bibliography [STY] Styles [CSS] Css definition-->


	<!--RULE -->
<xsl:template match="abbrev | ack | address | addr-line | aff | aff-alternatives | alternatives | alt-text | annotation | anonymous | attrib | author-comment | award-id | bio | chem-struct | chem-struct-wrap | conf-date | conf-loc | conf-name | conf-sponsor | contrib | contrib-group | country | def | def-head | def-item | def-list | elocation-id | fax | funding-source | glyph-data | glyph-ref | gov | inline-supplementary-material | institution | isbn | issn | journal-id | leading-org | long-desc | milestone-end | milestone-start | private-char | related-article | related-object | season | speaker | speech | trans-source | trans-title | verse-group | verse-line"
                 priority="1069"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="false()"/>
         <xsl:otherwise>
                [GEN_1] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should not be used
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="iso-meta" priority="1067" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="permissions"/>
         <xsl:otherwise>
                [META_1] missing permissions in <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="doc-ident" priority="1066" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(release-version = 'IS' and ../pub-date) or release-version != 'IS'"/>
         <xsl:otherwise>
                [META_2] doc-ident/release-version = IS requires element pub-date to be defined:: value '<xsl:text/>
            <xsl:value-of select="release-version"/>
            <xsl:text/>' 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="permissions" priority="1065" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="copyright-holder and copyright-year"/>
         <xsl:otherwise>
                [META_3] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> misses required copyright-holder and copyright-year
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT warn-->
<xsl:choose>
         <xsl:when test="copyright-statement"/>
         <xsl:otherwise>
                [META_31] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> misses copyright-statement
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="copyright-holder | copyright-year" priority="1064" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="normalize-space() != ''"/>
         <xsl:otherwise>
                [META_4] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> must not be empty 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="copyright-statement" priority="1063" mode="M7">

		<!--ASSERT warn-->
<xsl:choose>
         <xsl:when test="normalize-space() != ''"/>
         <xsl:otherwise>
                [META_5] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> is empty 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="content-language" priority="1062" mode="M7">
      <xsl:variable name="lang" select="."/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$lang = '' or preceding-sibling::title-wrap[@xml:lang = $lang]"/>
         <xsl:otherwise>
                [META_6] found <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> with '<xsl:text/>
            <xsl:value-of select="."/>
            <xsl:text/>' but no title in this language 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="doc-ref" priority="1061" mode="M7">
      <xsl:variable name="pub-year" select="substring(../pub-date, 1, 4)"/>
      <xsl:variable name="lang-ident" select="string-join(../content-language,',')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(., concat('.*\(', $lang-ident, '\)$'))"/>
         <xsl:otherwise>
                [META_7] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/>: '<xsl:text/>
            <xsl:value-of select="."/>
            <xsl:text/>' doesn't contain content-language <xsl:text/>
            <xsl:value-of select="$lang-ident"/>
            <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(../pub-date) or matches(., concat('.*:', $pub-year, '\(.*'))"/>
         <xsl:otherwise>
                [META_8] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/>: '<xsl:text/>
            <xsl:value-of select="."/>
            <xsl:text/>' doesn't contain year of publication <xsl:text/>
            <xsl:value-of select="$pub-year"/>
            <xsl:text/> 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="urn" priority="1060" mode="M7">
      <xsl:variable name="urn" select="fct:build-urn(ancestor::iso-meta)"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test=". = $urn"/>
         <xsl:otherwise>
                [META_9] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/>: <xsl:text/>
            <xsl:value-of select="."/>
            <xsl:text/> doesn't match urn build from matadata <xsl:text/>
            <xsl:value-of select="$urn"/>
            <xsl:text/> 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="std-ref[@type='dated']" priority="1059" mode="M7">
      <xsl:variable name="pub-year" select="substring(../pub-date, 1, 4)"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(../pub-date) or ends-with(., $pub-year)"/>
         <xsl:otherwise>
                [META_10] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/>[@type=dated]: <xsl:text/>
            <xsl:value-of select="."/>
            <xsl:text/> doesn't contain year of publication <xsl:text/>
            <xsl:value-of select="$pub-year"/>
            <xsl:text/> 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="front" priority="1057" mode="M7">

		<!--REPORT warn-->
<xsl:if test="count(sec[@sec-type='foreword'])&gt;1">
                [FRONT_1] <xsl:text/>
         <xsl:value-of select="name(.)"/>
         <xsl:text/> contain more than one "foreword" sec
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>

		    <!--REPORT warn-->
<xsl:if test="count(sec[@sec-type='intro'])&gt;1">
                [FRONT_2] <xsl:text/>
         <xsl:value-of select="name(.)"/>
         <xsl:text/> contains more than one "intro" sec
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="front//sec" priority="1056" mode="M7">

		<!--REPORT warn-->
<xsl:if test="@sec-type and not(index-of(('intro','foreword','abstract'), @sec-type))">
                [FRONT_3] <xsl:text/>
         <xsl:value-of select="name(.)"/>
         <xsl:text/> in front not of type "intro" or "foreword" <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="standard/body" priority="1054" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(.//sec[@sec-type='scope'] and not(ancestor::sub-part))=1"/>
         <xsl:otherwise>
                [BODY_1] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should contain a single "scope" sec
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(.//sec[@sec-type='norm-refs'] and not(ancestor::sub-part))&lt;=1"/>
         <xsl:otherwise>
                [BODY_2] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should not contain more than one "norm-refs" sec
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="standard/back" priority="1052" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(ref-list[@content-type='bibl'])&lt;=1"/>
         <xsl:otherwise>
                [BACK_1] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should not contain more than one ref-list (bibliography)
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="sec | term-sec" priority="1050" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@id or ancestor::boxed-text or (label = '' and not(title))"/>
         <xsl:otherwise>
                [SEC_1] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> must have @id
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="@sec-type and not(index-of((('intro','foreword','abstract','scope','norm-refs','terms')), @sec-type))">
                [SEC_2] <xsl:text/>
         <xsl:value-of select="name(.)"/>
         <xsl:text/> has unknown sec-type '<xsl:text/>
         <xsl:value-of select="@sec-type"/>
         <xsl:text/>'
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>

		    <!--REPORT warn-->
<xsl:if test="@sec-type = 'norm-refs' and .//list//std">
                [SEC_3] the norm-refs section uses std in normal list but should use ref-list
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="self::term-sec and not(ancestor::sec[@sec-type = 'terms'])">
                [SEC_4] <xsl:text/>
         <xsl:value-of select="name(.)"/>
         <xsl:text/> must be contained in a sec wich sec-type="terms"
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="sec[@sec-type='norm-refs']//ref-list/ref/std"
                 priority="1049"
                 mode="M7">

		<!--ASSERT -->
<xsl:choose>
         <xsl:when test="title"/>
         <xsl:otherwise>
                [SEC_5] std in norm-refs ref-list must have a title
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="app" priority="1048" mode="M7">
      <xsl:variable name="normlabel"
                    select="normalize-space(translate(label,'()&#x9; ','    '))"/>
      <xsl:variable name="labelsuffix" select="substring-after($normlabel,' ')"/>
      <xsl:variable name="labelsuffix"
                    select="if(string-length($labelsuffix)=0) then $normlabel else $labelsuffix"/>

		    <!--ASSERT warn-->
<xsl:choose>
         <xsl:when test="matches(@id, '^sec_[\w\._]+$')"/>
         <xsl:otherwise>
                [SEC_5] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should have id="<xsl:text/>
            <xsl:value-of select="concat('sec_',$labelsuffix)"/>
            <xsl:text/>"
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(label)=1"/>
         <xsl:otherwise>
                [SEC_6] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should contain a label
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(title)=1"/>
         <xsl:otherwise>
                [SEC_7] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should contain a title
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="fn" priority="1046" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@id or ancestor::fig or ancestor::table-wrap"/>
         <xsl:otherwise>
                [FN_1] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should have an id 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warn-->
<xsl:if test="not(ancestor::table-wrap) and not(ancestor::fig) and @id and not(matches(@id,'fn_\d+'))">
                [FN_2] @id of <xsl:text/>
         <xsl:value-of select="name(.)"/>
         <xsl:text/> should be "fn_" followed by sequential number # 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>

		    <!--REPORT warn-->
<xsl:if test="ancestor::table-wrap[not(contains(@content-type, 'index'))] and @id and not(starts-with(@id, 'table-fn_'))">
                [FN_3] @id of <xsl:text/>
         <xsl:value-of select="name(.)"/>
         <xsl:text/> should be "table-fn_" followed by footnote # (table footnote)
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="non-normative-note | non-normative-example"
                 priority="1044"
                 mode="M7">

		<!--ASSERT warn-->
<xsl:choose>
         <xsl:when test="label"/>
         <xsl:otherwise>
                [NOTE_1] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should have a label
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="@content-type and not(index-of(('warning','important','caution','danger','safety-precautions'), @content-type))">
                [NOTE_2] <xsl:text/>
         <xsl:value-of select="name(.)"/>
         <xsl:text/> has an invalid content-type
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="table-wrap[label]" priority="1042" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@id, '^(tab|fig)_[\w\.\-_]+$')"/>
         <xsl:otherwise>
                [TAB_1] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> with labels must have @id startig with tab_ (formal table)
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="td | th" priority="1041" mode="M7">

		<!--REPORT error-->
<xsl:if test="@colspan and not(matches(@colspan,'^\d+$') and xs:integer(@colspan) &gt; 0)">
                [TAB_2] invalid colspan value: <xsl:text/>
         <xsl:value-of select="./@colspan"/>
         <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="@rowspan and not(matches(@rowspan,'^\d+$') and xs:integer(@rowspan) &gt; 0)">
                [TAB_3] invalid rowspan value: <xsl:text/>
         <xsl:value-of select="./@rowspan"/>
         <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:variable name="css" select="css:parse(@style)"/>

		    <!--REPORT error-->
<xsl:if test="@style and $css//css:error">
                [TAB_4] problem in CSS <xsl:text/>
         <xsl:value-of select="$css//css:error"/>
         <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="table" priority="1040" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@width) or matches(@width, '^\d+(\.\d+)?(px|pt|[%])?$')"/>
         <xsl:otherwise>
                [TAB_5] attribute width for table is not a valid decimal @width=<xsl:text/>
            <xsl:value-of select="@width"/>
            <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="errors" select="fct:check-table(.)"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count($errors) = 0"/>
         <xsl:otherwise>
                [TAB_6] problem in table with @id=<xsl:text/>
            <xsl:value-of select="ancestor::table-wrap/@id"/>
            <xsl:text/>: <xsl:text/>
            <xsl:value-of select="$errors"/>
            <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="css" select="css:parse(@style)"/>

		    <!--REPORT error-->
<xsl:if test="@style and $css//css:error">
                [TAB_7] problem in CSS <xsl:text/>
         <xsl:value-of select="$css//css:error"/>
         <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="col/@width | colgroup/@width" priority="1039" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(., '^\d+(\.\d+)?(px|pt|[%])?$')"/>
         <xsl:otherwise>
                [TAB_8] attribute width for <xsl:text/>
            <xsl:value-of select="name(parent::node())"/>
            <xsl:text/> is not a valid decimal @width=<xsl:text/>
            <xsl:value-of select="."/>
            <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
     <!-- <xsl:apply-templates select="*" mode="M7"/> extracted by hand-->
   </xsl:template>

	  <!--RULE -->
<xsl:template match="disp-formula[@id and label]" priority="1037" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="label and matches(@id, '^formula_.*$')"/>
         <xsl:otherwise>
                [FOR_1] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> containing a label should have id starting with formula_ current value: <xsl:text/>
            <xsl:value-of select="@id"/>
            <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="disp-formula[not(@id)]" priority="1036" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(label) and not(@id)"/>
         <xsl:otherwise>
                [FOR_2] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> that doesn't contain a label should not have an id (unnumbered formula)
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="mml:math" priority="1034" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@id,'^mml_[\w\.\-_]+$')"/>
         <xsl:otherwise>
                [MML_1] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should have an id starting "mml_"
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="fig" priority="1032" mode="M7">
      <xsl:variable name="normlabel"
                    select="normalize-space(translate(label,'()&#x9; ','    '))"/>
      <xsl:variable name="labelsuffix" select="substring-after($normlabel,' ')"/>
      <xsl:variable name="labelsuffix"
                    select="if(string-length($labelsuffix)=0) then $normlabel else $labelsuffix"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@id, '^fig_[\w\.\-_]+$')"/>
         <xsl:otherwise>
                [FIG_1] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should have id="<xsl:text/>
            <xsl:value-of select="concat('fig_',$labelsuffix)"/>
            <xsl:text/>" matching its label
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="label"/>
         <xsl:otherwise>
                [FIG_2] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should contain a label (formal figure)
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT warn-->
<xsl:choose>
         <xsl:when test="caption/title"/>
         <xsl:otherwise>
                [FIG_3] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> does not contain a title (formal figure)
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="graphic or array or table-wrap or p/boxed-text"/>
         <xsl:otherwise>
                [FIG_4] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should have a graphic or table
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="tbx:termEntry" priority="1030" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@id, '^term_[\w\.]+$')"/>
         <xsl:otherwise>
                [TBX_1] @id of <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> must start with term_ current value is <xsl:text/>
            <xsl:value-of select="@id"/>
            <xsl:text/> 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="tbx:langSet" priority="1029" mode="M7">
      <xsl:variable name="tbx-lang" select="@xml:lang"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="index-of(('en','fr','ru','es','ar','de','zh'), @xml:lang)"/>
         <xsl:otherwise>
                [TBX_2] @xml:lang of <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> contains invalid value <xsl:text/>
            <xsl:value-of select="@xml:lang"/>
            <xsl:text/> 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT warn-->
<xsl:choose>
         <xsl:when test="count(tbx:tig) = 1 or not(tbx:tig[not(tbx:normativeAuthorization)])"/>
         <xsl:otherwise>
                [TBX_3] Whenever a term entry contains more than one term, you must rank them by using tbx:normativeAuthorization 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="//iso-meta[content-language = $tbx-lang]"/>
         <xsl:otherwise>
                [TBX_4] found tbx:langSet with xml:lang=<xsl:text/>
            <xsl:value-of select="$tbx-lang"/>
            <xsl:text/> value which is not defined as content-language 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="count(../tbx:langSet[@xml:lang = $tbx-lang]) &gt; 1">
                [TBX_41] found more than one tbx:langSet with xml:lang=<xsl:text/>
         <xsl:value-of select="$tbx-lang"/>
         <xsl:text/> for term: <xsl:text/>
         <xsl:value-of select="../@id"/>
         <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="tbx:see" priority="1028" mode="M7">
      <xsl:variable name="target" select="@target"/>

		    <!--REPORT error-->
<xsl:if test="@target and //tbx:termEntry[@id=$target]">
                [TBX_5] <xsl:text/>
         <xsl:value-of select="name(.)"/>
         <xsl:text/> should not be used to refer to other terms, use tbx:crossReference instead
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="tbx:crossReference" priority="1027" mode="M7">
      <xsl:variable name="target" select="@target"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@target) or //tbx:termEntry[@id=$target]"/>
         <xsl:otherwise>
                [TBX_6] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> does not reference a tbx:termEntry
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="tbx:definition" priority="1026" mode="M7">

		<!--ASSERT warn-->
<xsl:choose>
         <xsl:when test="not(matches(normalize-space(), '^\[.*\]$'))"/>
         <xsl:otherwise>
                [TBX_7] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> is enclosed with square brackets [], check if this should rather be a tbx:source
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="tbx:source" priority="1025" mode="M7">

		<!--ASSERT warn-->
<xsl:choose>
         <xsl:when test="not(matches(normalize-space(), '^\[.*\]$'))"/>
         <xsl:otherwise>
                [TBX_8] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should not be enclosed with square brackets []
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="xref" priority="1023" mode="M7">

		<!--ASSERT warn-->
<xsl:choose>
         <xsl:when test="@ref-type"/>
         <xsl:otherwise>
                [XREF_1] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should have a ref-type attribute
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@rid"/>
         <xsl:otherwise>
                [XREF_2] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should have an rid attribute
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="ref" priority="1021" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(std) &lt;= 1"/>
         <xsl:otherwise>
                [SREF_1] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> must contain only one std
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="sec/label | fig/label | table-wrap/label | app/label | term-sec/label"
                 priority="1019"
                 mode="M7">

		<!--REPORT warn-->
<xsl:if test="matches(., '.+[\s\-—\.:]$')">
                [LBL_1] <xsl:text/>
         <xsl:value-of select="name(.)"/>
         <xsl:text/> should not end in a space, tab, hyphen, m-dash, period, or colon
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="fig/graphic" priority="1017" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@xlink:href, concat('^', parent::fig/@id, '([\._][\w\.\-_]+)?$'))"/>
         <xsl:otherwise>
                [GRP_1] xlink:href of <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> within fig should start with <xsl:text/>
            <xsl:value-of select="../@id"/>
            <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="matches(@xlink:href, '.*\.(png|PNG)$')">
                [GRP_2] xlink:href of <xsl:text/>
         <xsl:value-of select="name(.)"/>
         <xsl:text/> references filename with type extension "<xsl:text/>
         <xsl:value-of select="@xlink:href"/>
         <xsl:text/>" (coding instruction)
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="table-wrap[@id]/graphic" priority="1016" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@xlink:href, '^(tab|img)_[\w\.\-_]+$')"/>
         <xsl:otherwise>
                [GRP_3] xlink:href of substitution graphic for table should be tab_# or img_#
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="graphic[not(ancestor::fig) and not(ancestor::table-wrap[@content-type='comparison']) and not(ancestor::boxed-text[@content-type='foreign-source'])]"
                 priority="1015"
                 mode="M7">

		<!--ASSERT warn-->
<xsl:choose>
         <xsl:when test="matches(@xlink:href, '^img_[\w\.\-_]+$')"/>
         <xsl:otherwise>
                [GRP_4] xlink:href of inline <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should be img_#
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="table-wrap[@content-type='comparison']//graphic"
                 priority="1014"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@xlink:href, '^cmp_\d_[\w\.\-_]+$')"/>
         <xsl:otherwise>
                [GRP_5] xlink:href of inline <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> in comparison table should be cmp_#_*
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="boxed-text[@content-type='foreign-source']//graphic"
                 priority="1013"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@xlink:href, '^fs_[\w\.\-_]+$')"/>
         <xsl:otherwise>
                [GRP_6] xlink:href of inline <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> in boxed-text with @content-type='foreign-source' should start with fs_*
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="list" priority="1011" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@list-type"/>
         <xsl:otherwise>
                [LST_1] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should have a list-type 
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="parent::p and not(ancestor::fn) and not(ancestor::table-wrap-foot)">
                [LST_2] <xsl:text/>
         <xsl:value-of select="name(.)"/>
         <xsl:text/> must be out side of p
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="list[@list-type = 'bullet']/list-item"
                 priority="1010"
                 mode="M7">

		<!--ASSERT warn-->
<xsl:choose>
         <xsl:when test="matches(label, '^[\-–−—•]$')"/>
         <xsl:otherwise>
                [LST_3] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> of @list-type = 'bullet' should use - — • as label
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="list[@list-type = 'simple']/list-item"
                 priority="1009"
                 mode="M7">

		<!--ASSERT warn-->
<xsl:choose>
         <xsl:when test="not(label)"/>
         <xsl:otherwise>
                [LST_4] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> of @list-type = 'simple' should not use label
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="back/ref-list" priority="1007" mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@content-type='bibl'"/>
         <xsl:otherwise>
                [BIB_1] <xsl:text/>
            <xsl:value-of select="name(.)"/>
            <xsl:text/> should have content-type="bibl" (bibliography)
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="ref-list[@content-type='bibl']" priority="1006" mode="M7">

		<!--ASSERT warn-->
<xsl:choose>
         <xsl:when test="../back"/>
         <xsl:otherwise>
                [BIB_2] bibl ref-list should be direct child of back
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@id"/>
         <xsl:otherwise>
                [BIB_3] bibl ref-list must have @id
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="back//ref-list/ref/label" priority="1005" mode="M7">

		<!--REPORT warn-->
<xsl:if test="matches(., '^\[\d+\]$') and not(ancestor::ref-list[@content-type='bibl'])">
                [BIB_4] ref-list label with [XX] in ref-list outside the bibl ref-list found
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="styled-content" priority="1003" mode="M7">

		<!--REPORT error-->
<xsl:if test="@style-type and not(index-of(('normal','addition'), @style-type))">
                [STY_1] <xsl:text/>
         <xsl:value-of select="name(.)"/>
         <xsl:text/> uses unknown style-type=<xsl:text/>
         <xsl:value-of select="@style-type"/>
         <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:variable name="css" select="css:parse(@style)"/>

		    <!--REPORT error-->
<xsl:if test="@style and $css//css:error">
                [STY_2] problem in CSS <xsl:text/>
         <xsl:value-of select="$css//css:error"/>
         <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="p" priority="1002" mode="M7">

		<!--REPORT error-->
<xsl:if test="@style-type and not(index-of(('align-left','align-right','align-center','valign-top','valign-bottom','valign-middle','indent'), @style-type))">
                [STY_3] <xsl:text/>
         <xsl:value-of select="name(.)"/>
         <xsl:text/> uses unknown style-type=<xsl:text/>
         <xsl:value-of select="@style-type"/>
         <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:variable name="css" select="css:parse(@style)"/>

		    <!--REPORT error-->
<xsl:if test="@style and $css//css:error">
                [STY_4] problem in CSS <xsl:text/>
         <xsl:value-of select="$css//css:error"/>
         <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
         <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                              select="."
                              mode="schematron-get-full-path-3"/>
         <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="*[@style]" priority="1000" mode="M7">
      <xsl:variable name="css" select="css:parse(@style)"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not($css//css:error)"/>
         <xsl:otherwise>
                [CSS_1] problem in CSS <xsl:text/>
            <xsl:value-of select="$css//css:error"/>
            <xsl:text/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron">: </xsl:text>
            <xsl:apply-templates xmlns:sch="http://www.ascc.net/xml/schematron"
                                 select="."
                                 mode="schematron-get-full-path-3"/>
            <xsl:text xmlns:sch="http://www.ascc.net/xml/schematron" xml:space="preserve">
</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M7"/>
   <xsl:template match="@*|node()" priority="-2" mode="M7">
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>
</xsl:stylesheet>
