<?xml version="1.0" encoding="US-ASCII"?>
<?xml-stylesheet type="text/xsl" href="../../xslstyle/xslstyle-docbook.xsl"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/XSL/Format"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:axf="http://www.antennahouse.com/names/XSL/Extensions"
                version="2.0"
                xmlns:xs="http://www.CraneSoftwrights.com/ns/xslstyle"
                xmlns:tbx="urn:iso:std:iso:30042:ed-1"
                xmlns:x="urn:X-Crane:isosts:xhtml"
                exclude-result-prefixes="xsd xs tbx">

<xs:doc filename="Crane-isosts2fo-a4.xsl" vocabulary="DocBook" internal-ns="c"
      info="$Id: Crane-isosts2fo-a4.xsl,v 1.29 2015/07/17 00:50:24 admin Exp $">
  <xs:title>ISO Standard Tag Set rendering with A4 page geometry</xs:title>
  <para>
    This renders an ISOSTS document with a layout similar to that prescribed
    by the ISO/IEC Directives.
  </para>
  <para>
    This module is a management module, pulling in the base fragment and
    defining all adaptable top-level parameters in an obvious fashion for
    users.
  </para>
</xs:doc>

<xsl:include href="support/Crane-isosts2fo-a4-base.xsl"/>

<!--========================================================================-->
<xs:doc>
  <xs:title>Adaptations for XSL-FO</xs:title>
</xs:doc>

<xs:param ignore-ns="yes">
  <para>
    The name of a parameters file to default invocation parameters.
  </para>
</xs:param>
<xsl:param name="Crane-ISOSTS-params-uri" as="xsd:string?"
           select="'Crane-ISOSTS-params.xml'"/>

<xs:param ignore-ns="yes">
  <para>
    The parameters file to default invocation parameters.
  </para>
</xs:param>
<xsl:param name="Crane-ISOSTS-params" as="document-node()?"
       select="for $uri in resolve-uri( $Crane-ISOSTS-params-uri, base-uri(/) )
               return if( doc-available( $uri ) ) then doc( $uri ) else ()"/>

<xs:param ignore-ns="yes">
  <para>
    Suppress the copyright
  </para>
</xs:param>
<xsl:param name="copyright-suppress" as="xsd:string"
       select="($Crane-ISOSTS-params/parameters/copyright-suppress,'yes')[1]"/>

<xs:param ignore-ns="yes">
  <para>
    A set of fall-back fonts to use with all font families in case the given
    family is missing a glyph.  Multiple names are comma-separated and names
    with spaces are quoted.
  </para>
</xs:param>
<xsl:param name="fallback-font-family-names" as="xsd:string"
           select="($Crane-ISOSTS-params/parameters/copyright-suppress,
                                '&#x22;Arial Unicode MS&#x22;,Helvetica')[1]"/>

<xs:param ignore-ns="yes">
  <para>
    Specify here image MIME content-type values supported for
    graphics using a white-space-separated list.
  </para>
</xs:param>
<xsl:param name="graphic-content-types" as="xsd:string" select="
  ( $Crane-ISOSTS-params/parameters/grahic-content-types,
' image/svg+xml image/cgm application/x-wmf application/x-eps application/x-bmp
image/x-wmf image/x-eps image/x-bmp image/jpeg image/png image/gif image/tiff
application/mathml+xml ' )[1]"/>
  
<xs:param ignore-ns="yes">
  <para>
    Specify here the extension to assume for all external images.
  </para>
</xs:param>
<xsl:param name="graphic-image-extension" as="xsd:string" 
 select="($Crane-ISOSTS-params/parameters/graphic-image-extension,'.png')[1]"/>
  
<xs:param ignore-ns="yes">
  <para>
    Specify here the prefix to add before graphic URIs found in the document.
  </para>
</xs:param>
<xsl:param name="graphic-uri-prefix" as="xsd:string" 
          select="($Crane-ISOSTS-params/parameters/graphic-uri-prefix,'')[1]"/>
  
<xs:param ignore-ns="yes">
  <para>
    The colour of links
  </para>
</xs:param>
<xsl:param name="links-with-blue" as="xsd:string"
          select="($Crane-ISOSTS-params/parameters/links-with-blue,'yes')[1]"/>

<xs:param ignore-ns="yes">
  <para>
    The decoration of links
  </para>
</xs:param>
<xsl:param name="links-with-underline" as="xsd:string"
     select="($Crane-ISOSTS-params/parameters/links-with-underline,'yes')[1]"/>

<xs:param ignore-ns="yes">
  <para>
    Suppress the copyright
  </para>
</xs:param>
<xsl:param name="metadata-suppress" as="xsd:string"
         select="($Crane-ISOSTS-params/parameters/metadata-suppress,'no')[1]"/>

<xs:param ignore-ns="yes">
  <para>
    The page height
  </para>
</xs:param>
<xsl:param name="page-height" as="xsd:string"
           select="($Crane-ISOSTS-params/parameters/page-width,'297mm')[1]"/>

<xs:param ignore-ns="yes">
  <para>
    The page width
  </para>
</xs:param>
<xsl:param name="page-width" as="xsd:string"
           select="($Crane-ISOSTS-params/parameters/page-width,'210mm')[1]"/>

<xs:param ignore-ns="yes">
  <para>
    Preview subset
  </para>
</xs:param>
<xsl:param name="preview" as="xsd:string"
           select="($Crane-ISOSTS-params/parameters/preview,'no')[1]"/>

<xs:param ignore-ns="yes">
  <para>
    Style of font
  </para>
</xs:param>
<xsl:param name="serif-font" as="xsd:string"
         select="($Crane-ISOSTS-params/parameters/serif-font,'yes')[1]"/>

<xs:param ignore-ns="yes">
  <para>
    Indentation in the table of contents
  </para>
</xs:param>
<xsl:param name="toc-indent-length" as="xsd:string"
       select="($Crane-ISOSTS-params/parameters/toc-indent-length,'12mm')[1]"/>

<xs:param ignore-ns="yes">
  <para>
    Depth of the table of contents
  </para>
</xs:param>
<xsl:param name="toc-max-depth" as="xsd:string"
         select="($Crane-ISOSTS-params/parameters/toc-max-depth,'3')[1]"/>

<!--========================================================================-->
<xs:doc>
  <xs:title>Adaptations passed on for XHTML/CSS</xs:title>
</xs:doc>

<xs:param ignore-ns="yes">
  <para>
    Specify here the element names that identify those instream child elements
    that are to be ignored as instream in PDF and XHTML because of the
    presumption that there is an equivalent graphic file associated with the
    image identifier.
  </para>
</xs:param>
<xsl:param name="pdf-xhtml-instream-elements-as-image" as="xsd:string?" 
select="$Crane-ISOSTS-params/parameters/pdf-xhtml-instream-elements-as-image"/>

<xs:param ignore-ns="yes">
  <para>The name and path to the CSS stylesheet for XHTML</para>
</xs:param>
<xsl:param name="xhtml-css-refer-uri" as="xsd:string?"
           select="$Crane-ISOSTS-params/parameters/xhtml-css-refer-uri"/>

<xs:param ignore-ns="yes">
  <para>The request to embed the given CSS into the XHTML</para>
</xs:param>
<xsl:param name="xhtml-css-embed" as="xsd:string?"
           select="$Crane-ISOSTS-params/parameters/xhtml-css-embed"/>

<xs:param ignore-ns="yes">
  <para>
    Specify here the element names that identify those instream child elements
    that are to be ignored as instream in XHTML because of the presumption
    that there is an equivalent graphic file associated with the image
    identifier.
  </para>
</xs:param>
<xsl:param name="xhtml-instream-elements-as-image" as="xsd:string?" 
     select="($Crane-ISOSTS-params/parameters/xhtml-instream-elements-as-image,
              'math mml:math')[1]"/>

<xs:param ignore-ns="yes">
  <para>
    Specify here the prefix to add before graphic URIs found in the document.
  </para>
</xs:param>
<xsl:param name="xhtml-instream-as-image-uri-prefix" as="xsd:string?" 
    select="($Crane-ISOSTS-params/parameters/xhtml-instream-as-image-uri-prefix,
             $graphic-uri-prefix)[1]"/>

<xs:param ignore-ns="yes">
  <para>
    Specify here the extension to assume for all external images for
    the substitution instream elements.
  </para>
</xs:param>
<xsl:param name="xhtml-instream-as-image-extension" as="xsd:string?" 
   select="($Crane-ISOSTS-params/parameters/xhtml-instream-as-image-uri-prefix,
            $graphic-image-extension,'.png')[1]"/>
  
</xsl:stylesheet>
